// ----------------------------------------------------------------------
// File: tetris_shape.pov
// Vers: 3.6
// Date: 04/18/2006
// Auth: H.A. Camp
//
// Desc: Tetris Surface Shape Definitions - Each object is defined as 
//       an actual POV object (xobj[...]) and a mask array 
//       (xmask[...][...]).  The mask array is used for placement 
//       checking, while the actual object is what gets added to the 
//       surface.
//

#declare xcnt = 15; // Total Number of Array Objects
#declare xobj = array[xcnt];
#declare xmask = array[xcnt][7];

#declare xset = 0;
// ...
// .x. (0)
// ...
#declare  xobj[xset] = object{Round_Box_Merge(<0,0,0>,<1,1,1>,0.15)};
#declare xmask[xset][0] = <0,0,0>;
#declare xset = xset + 1;

// ....
// .xx. (1)
// ....
#declare  xobj[xset] = object{Round_Box_Merge(<0,0,0>,<2,1,1>,0.15)};
#declare xmask[xset][0] = <0,0,0>;
#declare xmask[xset][1] = <1,0,0>;
#declare xset = xset + 1;

// .....
// .xxx. (2)
// .....
#declare  xobj[xset] = object{Round_Box_Merge(<0,0,0>,<3,1,1>,0.15)};
#declare xmask[xset][0] = <0,0,0>;
#declare xmask[xset][1] = <1,0,0>;
#declare xmask[xset][2] = <2,0,0>;
#declare xset = xset + 1;

// ....
// ..x.
// .xx. (3)
// ....
#declare  xobj[xset] = union{object{Round_Box_Merge(<0,0,0>,<2,1,1>,0.15) } object{Round_Box_Merge(<0,0,0>,<1,1,2>,0.15) translate x}};
#declare xmask[xset][0] = <0,0,0>;
#declare xmask[xset][1] = <1,0,0>;
#declare xmask[xset][2] = <1,0,1>;
#declare xset = xset + 1;

// .....
// ..xx.
// .xx.. (4)
// .....
#declare  xobj[xset] = union{object{Round_Box_Merge(<0,0,0>,<2,1,1>,0.15)} object{Round_Box_Merge(<0,0,0>,<2,1,1>,0.15) translate <1,0,1>} object{Round_Box_Merge(<0,0,0>,<1,1,2>,0.15) translate x}};
#declare xmask[xset][0] = <0,0,0>;
#declare xmask[xset][1] = <1,0,0>;
#declare xmask[xset][2] = <1,0,1>;
#declare xmask[xset][3] = <2,0,1>;
#declare xset = xset + 1;

// ....
// .xx.
// .xx. (5)
// ....
#declare  xobj[xset] = object{Round_Box_Merge(<0,0,0>,<2,1,2>,0.15)};
#declare xmask[xset][0] = <0,0,0>;
#declare xmask[xset][1] = <1,0,0>;
#declare xmask[xset][2] = <1,0,1>;
#declare xmask[xset][3] = <0,0,1>;
#declare xset = xset + 1;

// .....
// .xxx.
// .xxx. (6)
// .....
#declare  xobj[xset] = object{Round_Box_Merge(<0,0,0>,<3,1,2>,0.15)};
#declare xmask[xset][0] = <0,0,0>;
#declare xmask[xset][1] = <1,0,0>;
#declare xmask[xset][2] = <1,0,1>;
#declare xmask[xset][3] = <0,0,1>;
#declare xmask[xset][4] = <2,0,0>;
#declare xmask[xset][5] = <2,0,1>;
#declare xset = xset + 1;

// .....
// ..xx.
// .xxx. (7)
// .....
#declare  xobj[xset] = union{object{Round_Box_Merge(<0,0,0>,<2,1,2>,0.15) translate x} object{Round_Box_Merge(<0,0,0>,<3,1,1>,0.15)}};
#declare xmask[xset][0] = <0,0,0>;
#declare xmask[xset][1] = <1,0,0>;
#declare xmask[xset][2] = <2,0,0>;
#declare xmask[xset][3] = <1,0,1>;
#declare xmask[xset][4] = <2,0,1>;
#declare xset = xset + 1;

// .....
// ..x..
// .xxx. (8)
// .....
#declare  xobj[xset] = union{object{Round_Box_Merge(<0,0,0>,<3,1,1>,0.15) } object{Round_Box_Merge(<0,0,0>,<1,1,2>,0.15) translate x}};
#declare xmask[xset][0] = <0,0,0>;
#declare xmask[xset][1] = <1,0,0>;
#declare xmask[xset][2] = <2,0,0>;
#declare xmask[xset][3] = <1,0,1>;
#declare xset = xset + 1;

// .....
// .xxx.
// .ox.. (9)
// .....
#declare  xobj[xset] = union{object{Round_Box_Merge(<0,0,0>,<3,1,1>,0.15) translate z} object{Round_Box_Merge(<0,0,0>,<1,1,2>,0.15) translate x} object{xobj[0]}};
#declare xmask[xset][0] = <0,0,0>;
#declare xmask[xset][1] = <1,0,0>;
#declare xmask[xset][2] = <2,0,1>;
#declare xmask[xset][3] = <1,0,1>;
#declare xmask[xset][4] = <0,0,1>;
#declare xset = xset + 1;

// .....
// ..x..
// ..x.. (10)
// .xx..
// .....
#declare  xobj[xset] = union{object{Round_Box_Merge(<0,0,0>,<1,1,3>,0.15) translate x} object{Round_Box_Merge(<0,0,0>,<2,1,1>,0.15)}};
#declare xmask[xset][0] = <0,0,0>;
#declare xmask[xset][1] = <1,0,0>;
#declare xmask[xset][2] = <1,0,1>;
#declare xmask[xset][3] = <1,0,2>;
#declare xset = xset + 1;

// ......
// ...x..
// ...x.. (11)
// .xxx..
// ......
#declare  xobj[xset] = union{object{Round_Box_Merge(<0,0,0>,<1,1,3>,0.15) translate 2*x} object{Round_Box_Merge(<0,0,0>,<3,1,1>,0.15)}};
#declare xmask[xset][0] = <0,0,0>;
#declare xmask[xset][1] = <1,0,0>;
#declare xmask[xset][2] = <2,0,0>;
#declare xmask[xset][3] = <2,0,1>;
#declare xmask[xset][4] = <2,0,2>;
#declare xset = xset + 1;

// .....
// ..x..
// ..x..
// ..x.. (12)
// .xx..
// .....
#declare  xobj[xset] = union{object{Round_Box_Merge(<0,0,0>,<1,1,4>,0.15) translate x} object{Round_Box_Merge(<0,0,0>,<2,1,1>,0.15)}};
#declare xmask[xset][0] = <0,0,0>;
#declare xmask[xset][1] = <1,0,0>;
#declare xmask[xset][2] = <1,0,1>;
#declare xmask[xset][3] = <1,0,2>;
#declare xmask[xset][3] = <1,0,3>;
#declare xset = xset + 1;

// ...
// .x. (13)
// ...
//#declare  xobj[xset] = object{Round_Cylinder_Merge(<0,0.05,0>,<0,1.1,0>, 0.5, 0.15) translate <0.5,0,0.5>};
#declare  xobj[xset] = object{Round_Cylinder_Merge(<0,0.05,0>,<0,1,0>, 0.5, 0.15) translate <0.5,0,0.5>};
#declare xmask[xset][0] = <0,0,0>;
#declare xset = xset + 1;

// ...
// .x. (14)
// ...
#declare  xobj[xset] = object{Round_Box_Merge(<0,0,0>,<1,1,1>,0.15)};
#declare xmask[xset][0] = <0,0,0>;
#declare xset = xset + 1;
